==> reakit-1.2.1.tgz: package/es/Menu/index.js <==
import '../_rollupPluginBabelHelpers-1f0bf8c2.js';
import 'reakit-system/createComponent';
import 'reakit-system/createHook';
import 'reakit-utils/shallowEqual';
import '../Box/Box.js';
import 'react';
import 'reakit-utils/useForkRef';
import 'reakit-utils/isButton';
import 'reakit-warning';
import 'reakit-utils/useLiveRef';
import 'reakit-utils/isSelfTarget';
import 'reakit-utils/useIsomorphicEffect';
import 'reakit-utils/hasFocusWithin';
import 'reakit-utils/isPortalEvent';
import 'reakit-utils/getActiveElement';
import 'reakit-utils/tabbable';
import '../Tabbable/Tabbable.js';
import '../Clickable/Clickable.js';
import '../Button/Button.js';
import 'reakit-utils/removeIndexFromArray';
import 'reakit-utils/createEvent';
import '../Checkbox/Checkbox.js';
import 'reakit-utils/useSealedState';
import 'reakit-system/useCreateElement';
import 'reakit-utils/createOnKeyDown';
import 'reakit-utils/getDocument';
import 'reakit-utils/fireEvent';
import 'reakit-utils/fireKeyboardEvent';
import 'reakit-utils/getNextActiveElementOnBlur';
import '../reverse-30eaa122.js';
import '../getCurrentId-5aa9849e.js';
import '../findEnabledItemById-8ddca752.js';
import '../__keys-6b7fda7f.js';
import '../Composite/Composite.js';
import '../Group/Group.js';
import '../Id/IdProvider.js';
import '../Id/Id.js';
import '../Composite/CompositeGroup.js';
import 'reakit-utils/isTextField';
import '../setTextFieldValue-78ab5d56.js';
import '../Composite/CompositeItem.js';
import '../Composite/CompositeItemWidget.js';
import 'reakit-utils/applyState';
import '../Id/IdState.js';
import '../Composite/CompositeState.js';
import '../__keys-e6a5cfbe.js';
import '../Disclosure/DisclosureContent.js';
import 'react-dom';
import '../Portal/Portal.js';
import 'reakit-utils/removeItemFromArray';
import '../MenuContext-6af6cf92.js';
import '../Dialog/Dialog.js';
import 'body-scroll-lock';
import 'reakit-utils/useUpdateEffect';
import 'reakit-utils/closest';
import 'reakit-utils/contains';
import '../DialogBackdropContext-8775f78b.js';
import 'reakit-utils/isEmpty';
import '../__keys-ed7b48af.js';
import '../Disclosure/Disclosure.js';
import '../Dialog/DialogDisclosure.js';
import '../Disclosure/DisclosureState.js';
import '../Dialog/DialogState.js';
import 'reakit-warning/warning';
import '../__keys-018f251c.js';
import '../Radio/Radio.js';
import '../__keys-26bb1730.js';
import '../Popover/Popover.js';
export { MenuBar, useMenuBar } from './MenuBar.js';
import '../__keys-41337ef1.js';
export { Menu, useMenu } from './Menu.js';
import '../Popover/PopoverArrow.js';
export { MenuArrow, useMenuArrow } from './MenuArrow.js';
export { useMenuBarState } from './MenuBarState.js';
import '../Popover/PopoverDisclosure.js';
import '../findVisibleSubmenu-1553e354.js';
export { MenuButton, useMenuButton } from './MenuButton.js';
export { MenuDisclosure, useMenuDisclosure } from './MenuDisclosure.js';
export { MenuGroup, useMenuGroup } from './MenuGroup.js';
export { MenuItem, useMenuItem } from './MenuItem.js';
export { MenuItemCheckbox, useMenuItemCheckbox } from './MenuItemCheckbox.js';
export { MenuItemRadio, useMenuItemRadio } from './MenuItemRadio.js';
import '../Separator/Separator.js';
export { MenuSeparator, useMenuSeparator } from './MenuSeparator.js';
import '@popperjs/core';
import '../Popover/PopoverState.js';
export { useMenuState } from './MenuState.js';

==> reakit-1.2.2.tgz: package/es/Menu/index.js <==
import '../_rollupPluginBabelHelpers-1f0bf8c2.js';
import 'reakit-system/createComponent';
import 'reakit-system/createHook';
import 'reakit-utils/shallowEqual';
import '../Box/Box.js';
import 'react';
import 'reakit-utils/useForkRef';
import 'reakit-utils/isButton';
import 'reakit-warning';
import 'reakit-utils/useLiveRef';
import 'reakit-utils/isSelfTarget';
import 'reakit-utils/useIsomorphicEffect';
import 'reakit-utils/hasFocusWithin';
import 'reakit-utils/isPortalEvent';
import 'reakit-utils/getActiveElement';
import 'reakit-utils/tabbable';
import '../Tabbable/Tabbable.js';
import '../Clickable/Clickable.js';
import '../Button/Button.js';
import 'reakit-utils/removeIndexFromArray';
import 'reakit-utils/createEvent';
import '../Checkbox/Checkbox.js';
import 'reakit-utils/useSealedState';
import 'reakit-system/useCreateElement';
import 'reakit-utils/createOnKeyDown';
import 'reakit-utils/getDocument';
import 'reakit-utils/fireBlurEvent';
import 'reakit-utils/fireKeyboardEvent';
import 'reakit-utils/getNextActiveElementOnBlur';
import '../reverse-30eaa122.js';
import '../getCurrentId-5aa9849e.js';
import '../findEnabledItemById-8ddca752.js';
import '../__keys-6b7fda7f.js';
import '../Composite/Composite.js';
import '../Group/Group.js';
import '../Id/IdProvider.js';
import '../Id/Id.js';
import '../Composite/CompositeGroup.js';
import 'reakit-utils/isTextField';
import 'reakit-utils/ensureFocus';
import '../setTextFieldValue-78ab5d56.js';
import '../Composite/CompositeItem.js';
import '../Composite/CompositeItemWidget.js';
import 'reakit-utils/applyState';
import '../Id/IdState.js';
import '../Composite/CompositeState.js';
import '../__keys-e6a5cfbe.js';
import '../Disclosure/DisclosureContent.js';
import 'react-dom';
import '../Portal/Portal.js';
import 'reakit-utils/removeItemFromArray';
import '../MenuContext-6af6cf92.js';
import '../Dialog/Dialog.js';
import 'body-scroll-lock';
import 'reakit-utils/useUpdateEffect';
import 'reakit-utils/closest';
import 'reakit-utils/contains';
import '../DialogBackdropContext-8775f78b.js';
import 'reakit-utils/isEmpty';
import '../__keys-ed7b48af.js';
import '../Disclosure/Disclosure.js';
import '../Dialog/DialogDisclosure.js';
import '../Disclosure/DisclosureState.js';
import '../Dialog/DialogState.js';
import 'reakit-warning/warning';
import '../__keys-018f251c.js';
import '../Radio/Radio.js';
import '../__keys-26bb1730.js';
import '../Popover/Popover.js';
export { MenuBar, useMenuBar } from './MenuBar.js';
import '../__keys-41337ef1.js';
export { Menu, useMenu } from './Menu.js';
import '../Popover/PopoverArrow.js';
export { MenuArrow, useMenuArrow } from './MenuArrow.js';
export { useMenuBarState } from './MenuBarState.js';
import '../Popover/PopoverDisclosure.js';
import '../findVisibleSubmenu-1553e354.js';
export { MenuButton, useMenuButton } from './MenuButton.js';
export { MenuDisclosure, useMenuDisclosure } from './MenuDisclosure.js';
export { MenuGroup, useMenuGroup } from './MenuGroup.js';
export { MenuItem, useMenuItem } from './MenuItem.js';
export { MenuItemCheckbox, useMenuItemCheckbox } from './MenuItemCheckbox.js';
export { MenuItemRadio, useMenuItemRadio } from './MenuItemRadio.js';
import '../Separator/Separator.js';
export { MenuSeparator, useMenuSeparator } from './MenuSeparator.js';
import '@popperjs/core';
import '../Popover/PopoverState.js';
export { useMenuState } from './MenuState.js';
